@@ -9,11 +9,11 @@ from django.utils.translation import ugettext, ugettext_lazy as _
 from hvad.models import TranslatableModel, TranslatedFields
 
 DEFAULT_CHOICES = (
-    ('1', '1'),
-    ('2', '2'),
-    ('3', '3'),
-    ('4', '4'),
     ('5', '5'),
+    ('4', '4'),
+    ('3', '3'),
+    ('2', '2'),
+    ('1', '1'),
 )
 
 
@@ -97,13 +97,10 @@ class Review(models.Model):
             return self.user.email
         return ugettext('Anonymous')
 
-    def get_average_rating(self, max_value=None):
+    def get_averages(self, max_value=None):
         """
-        Returns the average rating for all categories of this review.
-
-        This is useful if you have several ratings for different categories
-        like ``Service``, ``Product Quality`` and want to show a total rating
-        for this review.
+        Centralized average calculation. Returns category averages and total
+        average.
 
         :param max_value: By default the app is set to a rating from 1 to 5.
           So if nothing is changed, we can just calculate the average of all
@@ -119,7 +116,7 @@ class Review(models.Model):
         """
         max_rating_value = 0
         category_maximums = {}
-        category_averages = []
+        category_averages = {}
         categories = RatingCategory.objects.filter(counts_for_average=True,
                                                    rating__review=self)
         # find the highest rating possible across all categories
@@ -134,27 +131,54 @@ class Review(models.Model):
         # calculate the average of every distinct category, normalized to the
         # recently found max
         for category in categories:
-            category_average = 0.0
+            category_average = None
             ratings = Rating.objects.filter(
                 category=category, value__isnull=False).exclude(value='')
             category_max = category_maximums[category]
             for rating in ratings:
-                category_average += float(rating.value)
+                if category_average is None:
+                    category_average = float(rating.value)
+                else:
+                    category_average += float(rating.value)
 
-            category_average *= float(max_rating_value) / float(category_max)
-            if category_average:
-                category_averages.append(category_average / ratings.count())
+            if category_average is not None:
+                category_average *= float(max_rating_value) / float(
+                    category_max)
+                category_averages[category] = (
+                    category_average / ratings.count())
 
         # calculate the total average of all categories
         total_average = 0
-        for category_average in category_averages:
+        for category, category_average in category_averages.iteritems():
             total_average += category_average
         if not len(category_averages):
-            return False
+            return (False, False)
         total_average /= len(category_averages)
 
+        return total_average, category_averages
+
+    def get_average_rating(self, max_value=None):
+        """
+        Returns the average rating for all categories of this review.
+
+        A shortcut for get_averages. Look there for more details.
+
+        """
+        total_average, category_averages = self.get_averages(
+            max_value=max_value)
         return total_average
 
+    def get_category_averages(self, max_value=None):
+        """
+        Returns the average ratings for every category of this review.
+
+        A shortcut for get_averages. Look there for more details.
+
+        """
+        total_average, category_averages = self.get_averages(
+            max_value=max_value)
+        return category_averages
+
     def is_editable(self):
         """
         Returns True, if the time period to update this review hasn't ended
@@ -225,7 +249,9 @@ class RatingCategory(TranslatableModel):
     categories, like ``Food``, ``Room service``, ``Cleansines`` and so on.
 
     :identifier: Optional identifier.
-    :name: Name of the category.
+    :name: Name of the category. Also used as label for the category form.
+    :question: If you want to render a more explicit question in addition to
+      the name, use this field. It is added to the form fields as help text.
     :counts_for_average: If True, the ratings of this category will be used to
       calculate the average rating. Default is True.
 
@@ -243,6 +269,7 @@ class RatingCategory(TranslatableModel):
 
     translations = TranslatedFields(
         name=models.CharField(max_length=256),
+        question=models.CharField(max_length=512, blank=True, null=True),
     )
 
     def __unicode__(self):
